@@ -1,19 +1,21 @@
 /* -*- Mode: C; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2; -*- */
-/* vim: set sw=2 ts=2 sts=2 et: */
-/*  Copyright © 2008 Xan Lopez <xan@gnome.org>
+/*
+ *  Copyright © 2008 Xan Lopez <xan@gnome.org>
  *
- *  This program is free software; you can redistribute it and/or modify
+ *  This file is part of Epiphany.
+ *
+ *  Epiphany is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2, or (at your option)
- *  any later version.
+ *  the Free Software Foundation, either version 3 of the License, or
+ *  (at your option) any later version.
  *
- *  This program is distributed in the hope that it will be useful,
+ *  Epiphany is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ *  along with Epiphany.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 #include <config.h>
@@ -37,7 +39,6 @@ typedef struct {
   void (*callback)(GSettings *settings, const char *key, gpointer data);
 } PrefData;
 
-#define ENABLE_SCRIPTS_SETTING "enable-javascript"
 #define DEFAULT_ENCODING_SETTING "default-charset"
 static WebKitSettings *webkit_settings = NULL;
 
@@ -118,7 +119,7 @@ webkit_pref_get_vendor_user_agent (void)
 
   branding_keyfile = g_key_file_new ();
 
-  if (g_key_file_load_from_file (branding_keyfile, SHARE_DIR "/branding.conf",
+  if (g_key_file_load_from_file (branding_keyfile, PKGDATADIR "/branding.conf",
                                  G_KEY_FILE_NONE, NULL)) {
     char *vendor;
     char *vendor_sub;
@@ -550,6 +551,8 @@ ephy_embed_prefs_init (gpointer user_data)
 
   webkit_settings = webkit_settings_new_with_settings ("enable-developer-extras", TRUE,
                                                        "enable-fullscreen", TRUE,
+                                                       "enable-javascript", TRUE,
+                                                       "enable-plugins", FALSE,
                                                        "enable-site-specific-quirks", TRUE,
                                                        "enable-dns-prefetching", TRUE,
                                                        "javascript-can-open-windows-automatically", TRUE,
@@ -582,18 +585,10 @@ ephy_embed_prefs_init (gpointer user_data)
                       G_CALLBACK (gtk_settings_xft_dpi_changed_cb), NULL);
   }
 
-  g_settings_bind (EPHY_SETTINGS_WEB,
-                   EPHY_PREFS_WEB_ENABLE_JAVASCRIPT,
-                   webkit_settings, ENABLE_SCRIPTS_SETTING,
-                   G_SETTINGS_BIND_GET);
   g_settings_bind (EPHY_SETTINGS_MAIN,
                    EPHY_PREFS_ENABLE_CARET_BROWSING,
                    webkit_settings, "enable-caret-browsing",
                    G_SETTINGS_BIND_GET);
-  g_settings_bind (EPHY_SETTINGS_WEB,
-                   EPHY_PREFS_WEB_ENABLE_PLUGINS,
-                   webkit_settings, "enable-plugins",
-                   G_SETTINGS_BIND_GET);
   g_settings_bind (EPHY_SETTINGS_WEB,
                    EPHY_PREFS_WEB_FONT_MIN_SIZE,
                    webkit_settings, "minimum-font-size",
