@@ -1,37 +1,38 @@
 /* -*- Mode: C; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
-/* vim: set sw=2 ts=2 sts=2 et: */
 /*
  *  Copyright © 2014 Igalia S.L.
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2, or (at your option)
- *  any later version.
+ *  This file is part of Epiphany.
  *
- *  This program is distributed in the hope that it will be useful,
+ *  Epiphany is free software: you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation, either version 3 of the License, or
+ *  (at your option) any later version.
+ *
+ *  Epiphany is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ *  along with Epiphany.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 #include "config.h"
 #include "ephy-web-extension.h"
 
+#include "ephy-dbus-names.h"
 #include "ephy-dbus-util.h"
 #include "ephy-debug.h"
 #include "ephy-embed-form-auth.h"
 #include "ephy-file-helpers.h"
 #include "ephy-form-auth-data.h"
+#include "ephy-hosts-manager.h"
 #include "ephy-prefs.h"
 #include "ephy-settings.h"
+#include "ephy-uri-tester-proxy.h"
 #include "ephy-web-dom-utils.h"
-#include "ephy-uri-helpers.h"
-#include "ephy-uri-tester.h"
 #include "ephy-web-overview.h"
-#include "ephy-web-extension-names.h"
 
 #include <gio/gio.h>
 #include <gtk/gtk.h>
@@ -39,7 +40,6 @@
 #include <string.h>
 #include <webkit2/webkit-web-extension.h>
 #define WEBKIT_DOM_USE_UNSTABLE_API
-#include <webkitdom/WebKitDOMCustomUnstable.h>
 #include <webkitdom/WebKitDOMDOMWindowUnstable.h>
 #include <JavaScriptCore/JavaScript.h>
 
@@ -51,12 +51,12 @@ struct _EphyWebExtension {
 
   GDBusConnection *dbus_connection;
   GCancellable *cancellable;
-  GArray *page_created_signals_pending;
 
-  EphyUriTester *uri_tester;
   EphyFormAuthDataCache *form_auth_data_cache;
   GHashTable *form_auth_data_save_requests;
   EphyWebOverviewModel *overview_model;
+  EphyHostsManager *hosts_manager;
+  EphyUriTesterProxy *uri_tester;
 };
 
 static const char introspection_xml[] =
@@ -112,52 +112,33 @@ web_page_send_request (WebKitWebPage     *web_page,
                        WebKitURIResponse *redirected_response,
                        EphyWebExtension  *extension)
 {
-  const char *original_request_uri;
   const char *request_uri;
   const char *page_uri;
-  gboolean ret;
-
-  request_uri = webkit_uri_request_get_uri (request);
-  original_request_uri = request_uri;
+  char *modified_uri;
 
   if (g_settings_get_boolean (EPHY_SETTINGS_WEB, EPHY_PREFS_WEB_DO_NOT_TRACK)) {
-    SoupMessageHeaders *headers;
-    char *new_uri;
-
-    headers = webkit_uri_request_get_http_headers (request);
+    SoupMessageHeaders *headers = webkit_uri_request_get_http_headers (request);
     if (headers) {
       /* Do Not Track header. '1' means 'opt-out'. See:
        * http://tools.ietf.org/id/draft-mayer-do-not-track-00.txt */
       soup_message_headers_append (headers, "DNT", "1");
     }
-
-    /* Remove analytics from URL before loading */
-    new_uri = ephy_remove_tracking_from_uri (request_uri);
-    if (new_uri) {
-      webkit_uri_request_set_uri (request, new_uri);
-      request_uri = webkit_uri_request_get_uri (request);
-    }
-    g_free (new_uri);
   }
 
-  if (!g_settings_get_boolean (EPHY_SETTINGS_WEB, EPHY_PREFS_WEB_ENABLE_ADBLOCK))
-    return FALSE;
-
+  request_uri = webkit_uri_request_get_uri (request);
   page_uri = webkit_web_page_get_uri (web_page);
 
-  /* Always load the main resource. */
-  if (g_strcmp0 (original_request_uri, page_uri) == 0)
-    return FALSE;
+  modified_uri = ephy_uri_tester_proxy_maybe_rewrite_uri (extension->uri_tester,
+                                                          request_uri,
+                                                          page_uri);
+  if (g_strcmp0 (request_uri, modified_uri) != 0) {
+    LOG ("Rewrote %s to %s", request_uri, modified_uri);
+    webkit_uri_request_set_uri (request,
+                                strlen (modified_uri) > 0 ? modified_uri : NULL);
+  }
+  g_free (modified_uri);
 
-  /* Always load data requests, as uri_tester won't do any good here. */
-  if (g_str_has_prefix (request_uri, SOUP_URI_SCHEME_DATA))
-    return FALSE;
-
-  ret = ephy_uri_tester_test_uri (extension->uri_tester, request_uri, page_uri);
-  if (ret)
-    g_debug ("Request '%s' blocked (page: '%s')", request_uri, page_uri);
-
-  return ret;
+  return FALSE;
 }
 
 static GHashTable *
@@ -213,15 +194,15 @@ store_password (EphyEmbedFormAuth *form_auth)
                              username_field_value,
                              password_field_value,
                              NULL, NULL);
+  g_free (uri_str);
 
   /* Update internal caching */
   ephy_form_auth_data_cache_add (extension->form_auth_data_cache,
-                                 uri_str,
+                                 uri->host,
                                  username_field_name,
                                  password_field_name,
                                  username_field_value);
 
-  g_free (uri_str);
   g_free (username_field_name);
   g_free (username_field_value);
   g_free (password_field_name);
@@ -280,40 +261,61 @@ should_store_cb (const char *username,
                  gpointer    user_data)
 {
   EphyEmbedFormAuth *form_auth = EPHY_EMBED_FORM_AUTH (user_data);
-  char *password_field_value = NULL;
+  EphyWebExtension *web_extension;
+  EphyHostPermission permission;
+  SoupURI *uri;
+  char *uri_string;
 
-  g_object_get (ephy_embed_form_auth_get_password_node (form_auth),
-                "value", &password_field_value, NULL);
-  if (password_field_value == NULL || strlen (password_field_value) == 0)
+  uri = ephy_embed_form_auth_get_uri (form_auth);
+  uri_string = soup_uri_to_string (uri, FALSE);
+  if (!uri_string)
+    return;
+
+  web_extension = ephy_web_extension_get ();
+  permission = ephy_hosts_manager_get_save_password_permission_for_address (web_extension->hosts_manager,
+                                                                            uri_string);
+
+  if (permission == EPHY_HOST_PERMISSION_DENY) {
+    LOG ("User/password storage permission previously denied. Not asking about storing.");
     goto out;
+  }
 
   if (password) {
     WebKitDOMNode *username_node;
     char *username_field_value = NULL;
+    char *password_field_value = NULL;
 
     username_node = ephy_embed_form_auth_get_username_node (form_auth);
     if (username_node)
       g_object_get (username_node, "value", &username_field_value, NULL);
+    g_object_get (ephy_embed_form_auth_get_password_node (form_auth),
+                  "value", &password_field_value, NULL);
 
     /* FIXME: We use only the first result, for now; We need to do
      * something smarter here */
     if (g_strcmp0 (username, username_field_value) == 0 &&
         g_str_equal (password, password_field_value)) {
       LOG ("User/password already stored. Not asking about storing.");
+    } else if (permission == EPHY_HOST_PERMISSION_ALLOW) {
+      LOG ("User/password not yet stored. Storing.");
+      store_password (form_auth);
     } else {
       LOG ("User/password not yet stored. Asking about storing.");
       request_decision_on_storing (g_object_ref (form_auth));
     }
 
     g_free (username_field_value);
+    g_free (password_field_value);
+  } else if (permission == EPHY_HOST_PERMISSION_ALLOW) {
+    LOG ("No result on query; storing.");
+    store_password (form_auth);
   } else {
     LOG ("No result on query; asking whether we should store.");
     request_decision_on_storing (g_object_ref (form_auth));
   }
 
 out:
-  if (password_field_value != NULL)
-    g_free (password_field_value);
+  g_free (uri_string);
 }
 
 static gboolean
@@ -371,26 +373,20 @@ fill_form_cb (const char *username,
               gpointer    user_data)
 {
   EphyEmbedFormAuth *form_auth = EPHY_EMBED_FORM_AUTH (user_data);
-  WebKitDOMHTMLInputElement *username_node;
-  WebKitDOMHTMLInputElement *password_node;
+  WebKitDOMNode *username_node;
 
   if (username == NULL && password == NULL) {
     LOG ("No result");
     return;
   }
 
-  username_node = WEBKIT_DOM_HTML_INPUT_ELEMENT (ephy_embed_form_auth_get_username_node (form_auth));
-  password_node = WEBKIT_DOM_HTML_INPUT_ELEMENT (ephy_embed_form_auth_get_password_node (form_auth));
+  username_node = ephy_embed_form_auth_get_username_node (form_auth);
 
   LOG ("Found: user %s pass (hidden)", username_node ? username : "(none)");
-  if (username_node) {
-    g_object_set_data (G_OBJECT (username_node), "ephy-is-auto-filling", GINT_TO_POINTER (TRUE));
-    webkit_dom_html_input_element_set_auto_filled (username_node, TRUE);
-    webkit_dom_html_input_element_set_editing_value (username_node, username);
-    g_object_set_data (G_OBJECT (username_node), "ephy-is-auto-filling", GINT_TO_POINTER (FALSE));
-  }
-  webkit_dom_html_input_element_set_auto_filled (password_node, TRUE);
-  webkit_dom_html_input_element_set_editing_value (password_node, password);
+  if (username_node)
+    g_object_set (username_node, "value", username, NULL);
+  g_object_set (ephy_embed_form_auth_get_password_node (form_auth),
+                "value", password, NULL);
 }
 
 static gint
@@ -434,15 +430,14 @@ pre_fill_form (EphyEmbedFormAuth *form_auth)
     return;
 
   extension = ephy_web_extension_get ();
-  uri_str = soup_uri_to_string (uri, FALSE);
-  form_auth_data_list = ephy_form_auth_data_cache_get_list (extension->form_auth_data_cache, uri_str);
+  form_auth_data_list = ephy_form_auth_data_cache_get_list (extension->form_auth_data_cache, uri->host);
   l = g_slist_find_custom (form_auth_data_list, form_auth, (GCompareFunc)ephy_form_auth_data_compare);
-  if (!l) {
-    g_free (uri_str);
+  if (!l)
     return;
-  }
 
   form_data = (EphyFormAuthData *)l->data;
+  uri_str = soup_uri_to_string (uri, FALSE);
+
   username_node = ephy_embed_form_auth_get_username_node (form_auth);
   if (username_node)
     g_object_get (username_node, "value", &username, NULL);
@@ -534,9 +529,12 @@ get_selected_bgcolor (void)
   GdkRGBA color;
   gtk_style_context_set_state (get_entry_style_context (),
                                GTK_STATE_FLAG_SELECTED);
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored "-Wdeprecated-declarations"
   gtk_style_context_get_background_color (get_entry_style_context (),
                                           GTK_STATE_FLAG_SELECTED,
                                           &color);
+#pragma GCC diagnostic pop
   return gdk_rgba_to_string (&color);
 }
 
@@ -558,9 +556,12 @@ get_bgcolor (void)
   GdkRGBA color;
   gtk_style_context_set_state (get_entry_style_context (),
                                GTK_STATE_FLAG_NORMAL);
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored "-Wdeprecated-declarations"
   gtk_style_context_get_background_color (get_entry_style_context (),
                                           GTK_STATE_FLAG_NORMAL,
                                           &color);
+#pragma GCC diagnostic pop
   return gdk_rgba_to_string (&color);
 }
 
@@ -898,9 +899,6 @@ username_node_input_cb (WebKitDOMNode  *username_node,
   WebKitDOMDocument *document;
   WebKitDOMElement *main_div;
 
-  if (g_object_get_data (G_OBJECT (username_node), "ephy-is-auto-filling"))
-    return TRUE;
-
   g_object_set_data (G_OBJECT (username_node), "ephy-user-ever-edited", GINT_TO_POINTER (TRUE));
   document = webkit_web_page_get_dom_document (web_page);
   remove_user_choices (document);
@@ -956,7 +954,8 @@ web_page_document_loaded (WebKitWebPage    *web_page,
     if (ephy_web_dom_utils_find_form_auth_elements (form, &username_node, &password_node)) {
       EphyEmbedFormAuth *form_auth;
       GSList *auth_data_list;
-      const char *uri;
+      const char *uri_string;
+      SoupURI *uri;
 
       LOG ("Hooking and pre-filling a form");
 
@@ -972,8 +971,12 @@ web_page_document_loaded (WebKitWebPage    *web_page,
       }
 
       /* Plug in the user autocomplete */
-      uri = webkit_web_page_get_uri (web_page);
-      auth_data_list = ephy_form_auth_data_cache_get_list (extension->form_auth_data_cache, uri);
+      uri_string = webkit_web_page_get_uri (web_page);
+      uri = soup_uri_new (uri_string);
+
+      auth_data_list = ephy_form_auth_data_cache_get_list (extension->form_auth_data_cache, uri->host);
+
+      soup_uri_free (uri);
 
       if (auth_data_list && auth_data_list->next && username_node) {
         LOG ("More than 1 password saved, hooking menu for choosing which on focus");
@@ -1075,34 +1078,6 @@ ephy_web_extension_emit_page_created (EphyWebExtension *extension,
   }
 }
 
-static void
-ephy_web_extension_emit_page_created_signals_pending (EphyWebExtension *extension)
-{
-  guint i;
-
-  if (!extension->page_created_signals_pending)
-    return;
-
-  for (i = 0; i < extension->page_created_signals_pending->len; i++) {
-    guint64 page_id;
-
-    page_id = g_array_index (extension->page_created_signals_pending, guint64, i);
-    ephy_web_extension_emit_page_created (extension, page_id);
-  }
-
-  g_array_free (extension->page_created_signals_pending, TRUE);
-  extension->page_created_signals_pending = NULL;
-}
-
-static void
-ephy_web_extension_queue_page_created_signal_emission (EphyWebExtension *extension,
-                                                       guint64           page_id)
-{
-  if (!extension->page_created_signals_pending)
-    extension->page_created_signals_pending = g_array_new (FALSE, FALSE, sizeof (guint64));
-  extension->page_created_signals_pending = g_array_append_val (extension->page_created_signals_pending, page_id);
-}
-
 static void
 ephy_web_extension_page_created_cb (EphyWebExtension *extension,
                                     WebKitWebPage    *web_page)
@@ -1110,10 +1085,7 @@ ephy_web_extension_page_created_cb (EphyWebExtension *extension,
   guint64 page_id;
 
   page_id = webkit_web_page_get_id (web_page);
-  if (extension->dbus_connection)
-    ephy_web_extension_emit_page_created (extension, page_id);
-  else
-    ephy_web_extension_queue_page_created_signal_emission (extension, page_id);
+  ephy_web_extension_emit_page_created (extension, page_id);
 
   g_signal_connect (web_page, "send-request",
                     G_CALLBACK (web_page_send_request),
@@ -1298,10 +1270,9 @@ ephy_web_extension_dispose (GObject *object)
 {
   EphyWebExtension *extension = EPHY_WEB_EXTENSION (object);
 
-// Leaked in gnome-3-22 to avoid crashes when destroyed in the exit handler.
-// Fixed in master by moving the UriTester to the UI process.
-//  g_clear_object (&extension->uri_tester);
   g_clear_object (&extension->overview_model);
+  g_clear_object (&extension->hosts_manager);
+
   g_clear_pointer (&extension->form_auth_data_cache,
                    ephy_form_auth_data_cache_free);
 
@@ -1310,15 +1281,7 @@ ephy_web_extension_dispose (GObject *object)
     extension->form_auth_data_save_requests = NULL;
   }
 
-  if (extension->page_created_signals_pending) {
-    g_array_free (extension->page_created_signals_pending, TRUE);
-    extension->page_created_signals_pending = NULL;
-  }
-
-  if (extension->cancellable) {
-    g_cancellable_cancel (extension->cancellable);
-    g_clear_object (&extension->cancellable);
-  }
+  g_clear_object (&extension->cancellable);
   g_clear_object (&extension->dbus_connection);
 
   g_clear_object (&extension->extension);
@@ -1353,49 +1316,6 @@ ephy_web_extension_get (void)
   return EPHY_WEB_EXTENSION (g_once (&once_init, ephy_web_extension_create_instance, NULL));
 }
 
-static void
-dbus_connection_created_cb (GObject          *source_object,
-                            GAsyncResult     *result,
-                            EphyWebExtension *extension)
-{
-  static GDBusNodeInfo *introspection_data = NULL;
-  GDBusConnection *connection;
-  guint registration_id;
-  GError *error = NULL;
-
-  if (!introspection_data)
-    introspection_data = g_dbus_node_info_new_for_xml (introspection_xml, NULL);
-
-  connection = g_dbus_connection_new_for_address_finish (result, &error);
-  if (error) {
-    g_warning ("Failed to connect to UI process: %s", error->message);
-    g_error_free (error);
-    g_object_unref (extension);
-    return;
-  }
-
-  registration_id =
-    g_dbus_connection_register_object (connection,
-                                       EPHY_WEB_EXTENSION_OBJECT_PATH,
-                                       introspection_data->interfaces[0],
-                                       &interface_vtable,
-                                       extension,
-                                       NULL,
-                                       &error);
-  if (!registration_id) {
-    g_warning ("Failed to register web extension object: %s\n", error->message);
-    g_error_free (error);
-    g_object_unref (connection);
-    g_object_unref (extension);
-    return;
-  }
-
-  extension->dbus_connection = connection;
-  ephy_web_extension_emit_page_created_signals_pending (extension);
-
-  g_object_unref (extension);
-}
-
 static gboolean
 authorize_authenticated_peer_cb (GDBusAuthObserver *observer,
                                  GIOStream         *stream,
@@ -1409,10 +1329,12 @@ void
 ephy_web_extension_initialize (EphyWebExtension   *extension,
                                WebKitWebExtension *wk_extension,
                                const char         *server_address,
-                               const char         *dot_dir,
                                gboolean            is_private_profile)
 {
+  static GDBusNodeInfo *introspection_data = NULL;
   GDBusAuthObserver *observer;
+  guint registration_id;
+  GError *error = NULL;
 
   g_return_if_fail (EPHY_IS_WEB_EXTENSION (extension));
 
@@ -1422,10 +1344,11 @@ ephy_web_extension_initialize (EphyWebExtension   *extension,
   extension->initialized = TRUE;
 
   extension->extension = g_object_ref (wk_extension);
-  extension->uri_tester = ephy_uri_tester_new (dot_dir);
   if (!is_private_profile)
     extension->form_auth_data_cache = ephy_form_auth_data_cache_new ();
 
+  extension->hosts_manager = ephy_hosts_manager_new ();
+
   g_signal_connect_swapped (extension->extension, "page-created",
                             G_CALLBACK (ephy_web_extension_page_created_cb),
                             extension);
@@ -1436,11 +1359,35 @@ ephy_web_extension_initialize (EphyWebExtension   *extension,
   g_signal_connect (observer, "authorize-authenticated-peer",
                     G_CALLBACK (authorize_authenticated_peer_cb), extension);
 
-  g_dbus_connection_new_for_address (server_address,
-                                     G_DBUS_CONNECTION_FLAGS_AUTHENTICATION_CLIENT,
-                                     observer,
-                                     extension->cancellable,
-                                     (GAsyncReadyCallback)dbus_connection_created_cb,
-                                     g_object_ref (extension));
+  /* Sync because this has to be ready before the first URI request, since
+   * WebKit does not provide any async way to rewrite URI requests. */
+  extension->dbus_connection =
+      g_dbus_connection_new_for_address_sync (server_address,
+                                              G_DBUS_CONNECTION_FLAGS_AUTHENTICATION_CLIENT,
+                                              observer,
+                                              NULL,
+                                              &error);
   g_object_unref (observer);
+
+  /* Fatal. */
+  if (error)
+    g_error ("Failed to connect to UI process: %s", error->message);
+
+  if (!introspection_data)
+    introspection_data = g_dbus_node_info_new_for_xml (introspection_xml, NULL);
+
+  registration_id =
+    g_dbus_connection_register_object (extension->dbus_connection,
+                                       EPHY_WEB_EXTENSION_OBJECT_PATH,
+                                       introspection_data->interfaces[0],
+                                       &interface_vtable,
+                                       extension,
+                                       NULL,
+                                       &error);
+
+  /* Fatal. */
+  if (!registration_id)
+    g_error ("Failed to register web extension object: %s\n", error->message);
+
+  extension->uri_tester = ephy_uri_tester_proxy_new (extension->dbus_connection);
 }
