@@ -3,22 +3,23 @@
  *  Copyright © 2000-2003 Marco Pesenti Gritti
  *  Copyright © 2010 Igalia S.L.
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2, or (at your option)
- *  any later version.
+ *  This file is part of Epiphany.
  *
- *  This program is distributed in the hope that it will be useful,
+ *  Epiphany is free software: you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation, either version 3 of the License, or
+ *  (at your option) any later version.
+ *
+ *  Epiphany is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ *  along with Epiphany.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef EPHY_PREFS_H
-#define EPHY_PREFS_H
+#pragma once
 
 G_BEGIN_DECLS
 
@@ -85,8 +86,6 @@ typedef enum
 #define EPHY_PREFS_WEB_USE_OWN_COLORS        "use-own-colors"
 #define EPHY_PREFS_WEB_ENABLE_USER_CSS       "enable-user-css"
 #define EPHY_PREFS_WEB_ENABLE_POPUPS         "enable-popups"
-#define EPHY_PREFS_WEB_ENABLE_PLUGINS        "enable-plugins"
-#define EPHY_PREFS_WEB_ENABLE_JAVASCRIPT     "enable-javascript"
 #define EPHY_PREFS_WEB_ENABLE_SPELL_CHECKING "enable-spell-checking"
 #define EPHY_PREFS_WEB_ENABLE_WEBGL          "enable-webgl"
 #define EPHY_PREFS_WEB_ENABLE_WEBAUDIO       "enable-webaudio"
@@ -111,6 +110,8 @@ typedef enum
 #define EPHY_PREFS_RESTORE_SESSION_DELAYING_LOADS "restore-session-delaying-loads"
 #define EPHY_PREFS_PROCESS_MODEL                  "process-model"
 #define EPHY_PREFS_MAX_PROCESSES                  "max-processes"
+#define EPHY_PREFS_SYNC_USER                      "sync-user"
+#define EPHY_PREFS_SYNC_TIME                      "sync-time"
 
 #define EPHY_PREFS_LOCKDOWN_SCHEMA            "org.gnome.Epiphany.lockdown"
 #define EPHY_PREFS_LOCKDOWN_FULLSCREEN        "disable-fullscreen"
@@ -119,11 +120,6 @@ typedef enum
 #define EPHY_PREFS_LOCKDOWN_HISTORY           "disable-history"
 #define EPHY_PREFS_LOCKDOWN_SAVE_TO_DISK      "disable-save-to-disk"
 #define EPHY_PREFS_LOCKDOWN_PRINTING          "disable-printing"
-#define EPHY_PREFS_LOCKDOWN_PRINT_SETUP       "disable-print-setup"
-#define EPHY_PREFS_LOCKDOWN_COMMAND_LINE      "disable-command-line"
 #define EPHY_PREFS_LOCKDOWN_QUIT              "disable-quit"
-#define EPHY_PREFS_LOCKDOWN_JAVASCRIPT_CHROME "disable-javascript-chrome"
 
 G_END_DECLS
-
-#endif
