@@ -1,18 +1,21 @@
 /* -*- Mode: C; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2; -*- */
-/* *  Copyright © 2011 Igalia S.L.
+/*
+ *  Copyright © 2011 Igalia S.L.
  *
- *  This program is free software; you can redistribute it and/or modify
+ *  This file is part of Epiphany.
+ *
+ *  Epiphany is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2, or (at your option)
- *  any later version.
+ *  the Free Software Foundation, either version 3 of the License, or
+ *  (at your option) any later version.
  *
- *  This program is distributed in the hope that it will be useful,
+ *  Epiphany is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ *  along with Epiphany.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 #include "config.h"
@@ -22,6 +25,7 @@
 #include "ephy-history-types.h"
 #include "ephy-history-type-builtins.h"
 #include "ephy-sqlite-connection.h"
+#include "ephy-uri-helpers.h"
 
 typedef gboolean (*EphyHistoryServiceMethod)      (EphyHistoryService *self, gpointer data, gpointer *result);
 
@@ -946,7 +950,7 @@ ephy_history_service_execute_set_url_thumbnail_time (EphyHistoryService *self,
                                                      EphyHistoryURL     *url,
                                                      gpointer           *result)
 {
-  int thumbnail_time;
+  gint64 thumbnail_time;
 
   if (self->read_only)
     return FALSE;
@@ -966,7 +970,7 @@ ephy_history_service_execute_set_url_thumbnail_time (EphyHistoryService *self,
 void
 ephy_history_service_set_url_thumbnail_time (EphyHistoryService    *self,
                                              const char            *orig_url,
-                                             int                    thumbnail_time,
+                                             gint64                 thumbnail_time,
                                              GCancellable          *cancellable,
                                              EphyHistoryJobCallback callback,
                                              gpointer               user_data)
@@ -1290,13 +1294,16 @@ ephy_history_service_visit_url (EphyHistoryService      *self,
                                 EphyHistoryPageVisitType visit_type)
 {
   EphyHistoryPageVisit *visit;
+  char *sanitized_uri;
 
   g_return_if_fail (EPHY_IS_HISTORY_SERVICE (self));
   g_return_if_fail (url != NULL);
 
   g_signal_emit (self, signals[VISIT_URL], 0, url, visit_type);
 
-  visit = ephy_history_page_visit_new (url,
+  sanitized_uri = ephy_uri_sanitize (url);
+
+  visit = ephy_history_page_visit_new (sanitized_uri,
                                        time (NULL),
                                        visit_type);
   ephy_history_service_add_visit (self,
@@ -1304,6 +1311,8 @@ ephy_history_service_visit_url (EphyHistoryService      *self,
   ephy_history_page_visit_free (visit);
 
   ephy_history_service_queue_urls_visited (self);
+
+  g_free (sanitized_uri);
 }
 
 void
