@@ -1,27 +1,28 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
+/* -*- Mode: C; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
 /*
  *  Copyright © 2003, 2004 Marco Pesenti Gritti <mpeseng@tin.it>
  *  Copyright © 2003, 2004 Christian Persch
  *  Copyright © 2012 Igalia S.L
  *
- *  This program is free software; you can redistribute it and/or modify
+ *  This file is part of Epiphany.
+ *
+ *  Epiphany is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
+ *  the Free Software Foundation, either version 3 of the License, or
  *  (at your option) any later version.
  *
- *  This program is distributed in the hope that it will be useful,
+ *  Epiphany is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ *  along with Epiphany.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 #include "config.h"
 #include "ephy-history-window.h"
 
-#include "ephy-bookmarks-ui.h"
 #include "ephy-debug.h"
 #include "ephy-gui.h"
 #include "ephy-prefs.h"
@@ -66,8 +67,6 @@ struct _EphyHistoryWindow {
   gboolean sort_ascending;
   gint sort_column;
 
-  GtkWidget *window;
-
   GtkWidget *confirmation_dialog;
 };
 
@@ -286,11 +285,7 @@ forget_all (GSimpleAction *action,
 static GtkWidget *
 get_target_window (EphyHistoryWindow *self)
 {
-  if (self->window) {
-    return self->window;
-  } else {
     return GTK_WIDGET (gtk_application_get_active_window (GTK_APPLICATION (ephy_shell_get_default ())));
-  }
 }
 
 static void
@@ -402,27 +397,6 @@ copy_url (GSimpleAction *action,
   g_list_free_full (selection, (GDestroyNotify)ephy_history_url_free);
 }
 
-static void
-bookmark (GSimpleAction *action,
-          GVariant      *parameter,
-          gpointer       user_data)
-{
-  EphyHistoryWindow *self = EPHY_HISTORY_WINDOW (user_data);
-  GList *selection;
-
-  selection = get_selection (self);
-
-  if (g_list_length (selection) == 1) {
-    EphyHistoryURL *url;
-
-    url = selection->data;
-
-    ephy_bookmarks_ui_add_bookmark (GTK_WINDOW (self), url->url, url->title);
-  }
-
-  g_list_free_full (selection, (GDestroyNotify)ephy_history_url_free);
-}
-
 static void
 forget (GSimpleAction *action,
         GVariant      *parameter,
@@ -452,16 +426,10 @@ update_popup_menu_actions (GActionGroup *action_group,
                            gboolean      only_one_selected_item)
 {
   GAction *copy_url_action;
-  GAction *bookmark_action;
-  gboolean bookmarks_locked;
 
   copy_url_action = g_action_map_lookup_action (G_ACTION_MAP (action_group), "copy-url");
-  bookmark_action = g_action_map_lookup_action (G_ACTION_MAP (action_group), "bookmark");
-  bookmarks_locked = g_settings_get_boolean (EPHY_SETTINGS_LOCKDOWN,
-                                             EPHY_PREFS_LOCKDOWN_BOOKMARK_EDITING);
 
   g_simple_action_set_enabled (G_SIMPLE_ACTION (copy_url_action), only_one_selected_item);
-  g_simple_action_set_enabled (G_SIMPLE_ACTION (bookmark_action), (only_one_selected_item && !bookmarks_locked));
 }
 
 static gboolean
@@ -481,7 +449,7 @@ on_treeview_button_press_event (GtkWidget         *widget,
 
     menu = gtk_menu_new_from_model (self->treeview_popup_menu_model);
     gtk_menu_attach_to_widget (GTK_MENU (menu), GTK_WIDGET (self), NULL);
-    gtk_menu_popup (GTK_MENU (menu), NULL, NULL, NULL, NULL, event->button, event->time);
+    gtk_menu_popup_at_pointer (GTK_MENU (menu), (GdkEvent *)event);
     return TRUE;
   }
 
@@ -672,29 +640,12 @@ ephy_history_window_dispose (GObject *object)
   G_OBJECT_CLASS (ephy_history_window_parent_class)->dispose (object);
 }
 
-static void
-ephy_history_window_finalize (GObject *object)
-{
-  EphyHistoryWindow *self = EPHY_HISTORY_WINDOW (object);
-
-  if (self->window) {
-    GtkWidget **window = &self->window;
-    g_object_remove_weak_pointer
-      (G_OBJECT (self->window),
-      (gpointer *)window);
-  }
-
-  G_OBJECT_CLASS (ephy_history_window_parent_class)->finalize (object);
-}
-
 static void
 ephy_history_window_class_init (EphyHistoryWindowClass *klass)
 {
   GObjectClass *object_class = G_OBJECT_CLASS (klass);
   GtkWidgetClass *widget_class = GTK_WIDGET_CLASS (klass);
 
-  object_class->finalize = ephy_history_window_finalize;
-
   object_class->set_property = ephy_history_window_set_property;
   object_class->get_property = ephy_history_window_get_property;
   object_class->dispose = ephy_history_window_dispose;
@@ -737,7 +688,7 @@ convert_date_data_func (GtkTreeViewColumn *column,
                         gpointer           user_data)
 {
   int col_id = GPOINTER_TO_INT (user_data);
-  int value;
+  gint64 value;
   time_t time;
   char *friendly;
 
@@ -767,7 +718,7 @@ convert_location_data_func (GtkTreeViewColumn *column,
                       col_id,
                       &url,
                       -1);
-  decoded_url = ephy_uri_decode (url);
+  decoded_url = ephy_uri_decode_and_sanitize (url);
 
   g_object_set (renderer, "text", decoded_url, NULL);
 
@@ -796,7 +747,6 @@ create_action_group (EphyHistoryWindow *self)
   const GActionEntry entries[] = {
     { "open-selection", open_selection },
     { "copy-url", copy_url },
-    { "bookmark", bookmark },
     { "forget", forget },
     { "forget-all", forget_all }
   };
