@@ -1,22 +1,24 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
+/* -*- Mode: C; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
 /*
  *  Copyright © 2002 Jorn Baayen
  *  Copyright © 2003, 2004 Marco Pesenti Gritti
  *  Copyright © 2003, 2004, 2005, 2006, 2008 Christian Persch
  *  Copyright © 2012 Igalia S.L.
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2, or (at your option)
- *  any later version.
+ *  This file is part of Epiphany.
  *
- *  This program is distributed in the hope that it will be useful,
+ *  Epiphany is free software: you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation, either version 3 of the License, or
+ *  (at your option) any later version.
+ *
+ *  Epiphany is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ *  along with Epiphany.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 #include "config.h"
@@ -697,28 +699,33 @@ write_tab (xmlTextWriterPtr writer,
   int ret;
 
   ret = xmlTextWriterStartElement (writer, (xmlChar *)"embed");
-  if (ret < 0) return ret;
+  if (ret < 0)
+    return ret;
 
   ret = xmlTextWriterWriteAttribute (writer, (xmlChar *)"url",
                                      (const xmlChar *)tab->url);
-  if (ret < 0) return ret;
+  if (ret < 0)
+    return ret;
 
   ret = xmlTextWriterWriteAttribute (writer, (xmlChar *)"title",
                                      (const xmlChar *)tab->title);
-  if (ret < 0) return ret;
+  if (ret < 0)
+    return ret;
 
   if (tab->loading) {
     ret = xmlTextWriterWriteAttribute (writer,
                                        (const xmlChar *)"loading",
                                        (const xmlChar *)"true");
-    if (ret < 0) return ret;
+    if (ret < 0)
+      return ret;
   }
 
   if (tab->crashed) {
     ret = xmlTextWriterWriteAttribute (writer,
                                        (const xmlChar *)"crashed",
                                        (const xmlChar *)"true");
-    if (ret < 0) return ret;
+    if (ret < 0)
+      return ret;
   }
 
   if (tab->state) {
@@ -753,15 +760,18 @@ write_window_geometry (xmlTextWriterPtr writer,
   /* set window properties */
   ret = xmlTextWriterWriteFormatAttribute (writer, (const xmlChar *)"x", "%d",
                                            geometry->x);
-  if (ret < 0) return ret;
+  if (ret < 0)
+    return ret;
 
   ret = xmlTextWriterWriteFormatAttribute (writer, (const xmlChar *)"y", "%d",
                                            geometry->y);
-  if (ret < 0) return ret;
+  if (ret < 0)
+    return ret;
 
   ret = xmlTextWriterWriteFormatAttribute (writer, (const xmlChar *)"width", "%d",
                                            geometry->width);
-  if (ret < 0) return ret;
+  if (ret < 0)
+    return ret;
 
   ret = xmlTextWriterWriteFormatAttribute (writer, (const xmlChar *)"height", "%d",
                                            geometry->height);
@@ -776,28 +786,34 @@ write_ephy_window (xmlTextWriterPtr writer,
   int ret;
 
   ret = xmlTextWriterStartElement (writer, (xmlChar *)"window");
-  if (ret < 0) return ret;
+  if (ret < 0)
+    return ret;
 
   ret = write_window_geometry (writer, &window->geometry);
-  if (ret < 0) return ret;
+  if (ret < 0)
+    return ret;
 
   ret = xmlTextWriterWriteFormatAttribute (writer, (const xmlChar *)"active-tab", "%d",
                                            window->active_tab);
-  if (ret < 0) return ret;
+  if (ret < 0)
+    return ret;
 
   if (window->role != NULL) {
     ret = xmlTextWriterWriteAttribute (writer,
                                        (const xmlChar *)"role",
                                        (const xmlChar *)window->role);
-    if (ret < 0) return ret;
+    if (ret < 0)
+      return ret;
   }
 
   for (l = window->tabs; l != NULL; l = l->next) {
     SessionTab *tab = (SessionTab *)l->data;
     ret = write_tab (writer, tab);
-    if (ret < 0) break;
+    if (ret < 0)
+      break;
   }
-  if (ret < 0) return ret;
+  if (ret < 0)
+    return ret;
 
   ret = xmlTextWriterEndElement (writer);       /* window */
   return ret;
@@ -855,31 +871,38 @@ save_session_sync (GTask        *task,
 
   buffer = xmlBufferCreate ();
   writer = xmlNewTextWriterMemory (buffer, 0);
-  if (writer == NULL) goto out;
+  if (writer == NULL)
+    goto out;
 
   ret = xmlTextWriterSetIndent (writer, 1);
-  if (ret < 0) goto out;
+  if (ret < 0)
+    goto out;
 
   ret = xmlTextWriterSetIndentString (writer, (const xmlChar *)"	 ");
-  if (ret < 0) goto out;
+  if (ret < 0)
+    goto out;
 
   START_PROFILER ("Saving session")
 
   ret = xmlTextWriterStartDocument (writer, "1.0", NULL, NULL);
-  if (ret < 0) goto out;
+  if (ret < 0)
+    goto out;
 
   /* create and set the root node for the session */
   ret = xmlTextWriterStartElement (writer, (const xmlChar *)"session");
-  if (ret < 0) goto out;
+  if (ret < 0)
+    goto out;
 
   /* iterate through all the windows */
   for (w = data->windows; w != NULL && ret >= 0; w = w->next) {
     ret = write_ephy_window (writer, (SessionWindow *)w->data);
   }
-  if (ret < 0) goto out;
+  if (ret < 0)
+    goto out;
 
   ret = xmlTextWriterEndElement (writer);       /* session */
-  if (ret < 0) goto out;
+  if (ret < 0)
+    goto out;
 
   ret = xmlTextWriterEndDocument (writer);
 
@@ -1083,7 +1106,6 @@ session_parse_window (SessionParserContext *context,
   }
 
   restore_geometry (GTK_WINDOW (context->window), &geometry);
-  ephy_gui_window_update_user_time (GTK_WIDGET (context->window), context->user_time);
 }
 
 static void
